use quic_demo::prelude::*;

#[tokio::main]
async fn main () -> anyhow::Result <()> {
	tracing_subscriber::fmt::init ();
	
	let server_cert = tokio::fs::read ("quic_server.crt").await?;
	let server_addr = "127.0.0.1:30380".parse ()?;
	let endpoint = make_client_endpoint ("0.0.0.0:0".parse ()?, &[&server_cert])?;
	
	debug! ("Connecting to relay server");
	
	let quinn::NewConnection {
		mut bi_streams,
		..
	} = endpoint.connect (&server_addr, "localhost")?.await?;
	
	debug! ("Waiting for incoming bi stream");
	
	let (mut send, mut recv) = bi_streams.next ().await.ok_or_else (|| anyhow::anyhow! ("Relay server didn't open a bi stream"))??;
	
	let mut buf = vec! [0u8; 65_536];
	while let Some (bytes_read) = recv.read (&mut buf).await? {
		let s = format! ("bytes_read: {}", bytes_read);
		send.write_all (s.as_bytes ()).await?;
	}
	
	Ok (())
}
